==> smsalert-0.1.2.tar.gz: lib/src/messages.dart <==
// messages.dart
import 'dart:core';
import 'dart:convert' show json;
import 'package:http/http.dart' as http;
import './constants.dart';
import './utils.dart';

class Messages {
  final String _user;
  final String _pwd;

  const Messages(this._user, this._pwd);

//Send SMS
  Future<Map?> sendsms(data) async {
    Map? sendsms = await callapi('push', data);
    return (sendsms);
  }

//Schedule SMS
  Future<Map?> schedulesms(data) async {
    Map? schedulesms = await callapi('push', data);
    return (schedulesms);
  }

//Credit status
  Future<Map?> creditstatus() async {
    Map? creditstatus = await callapi('creditstatus');
    return (creditstatus);
  }

//SenderID list
  Future<Map?> senderlist() async {
    Map? senderID = await callapi('senderlist');
    return (senderID);
  }

//Generate otp
  Future<Map?> sendotp(data) async {
    Map? sendotp = await callapi('mverify', data);
    return (sendotp);
  }

//Verify otp
  Future<Map?> verifyotp(data) async {
    Map? verifyotp = await callapi('mverify', data);
    return (verifyotp);
  }

//used to send sms report
  Future<Map?> smsreport(data) async {
    Map? smsreport = await callapi('smscampaignlog', data);
    return (smsreport);
  }

//used to pull sms report
  Future<Map?> pullreport(data) async {
    Map? pullreport = await callapi('pull', data);
    return (pullreport);
  }

//get countries list
  Future<Map?> getcountries() async {
    Map? getcountries = await callapi('countrylist');
    return (getcountries);
  }

//used to send group sms
  Future<Map?> sendgroupsms(data) async {
    Map? sendgroupsms = await callapi('grouppush', data);
    return (sendgroupsms);
  }

//used to create contact
  Future<Map?> createcontact(data) async {
    Map? createcontact = await callapi('createcontact', data);
    return (createcontact);
  }

  ///to call any api function
//Parameters accepted:
  /// 1. action_name='<API url endpoint>' (eg.push,creditstatus,etc)
  /* 2. var datas = {
          'sender': 'CVDEMO',
          'mobileno': '918010551055',
          'text': 'Hello from Dart!', 
          'route':'demo'
            }; */

  Future<Map?> callapi(action_name, [datas]) async {
    http.Client client = http.Client();

    String url = '${SMSALERT_API_BASE_URL}/$action_name.json';

    try {
      http.Response response = await client.post(Uri.parse(url),
          headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
            'Authorization': 'Basic ' + toAuthCredentials(_user, _pwd)
          },
          body: datas);

      return (json.decode(response.body));
    } catch (e) {
      return ({'Runtime Error': e});
    } finally {
      client.close();
    }
  }

//format number experimental
  /* formatNumber(mobileno) {
    var prefix = 91;
    var nos = (mobileno.split(","));
    List valid_no = [];
    for (String no in nos) {
      no = no.replaceAll(new RegExp(r"(\D)"), "");
      no = no.replaceFirst(new RegExp(r"^[+0]+"), "");
      var res = '$prefix'.matchAsPrefix(no);

      var temp = no.substring(0, '$prefix'.length);

      if (res == null) {
        if (no.length == 10) {
          no = '$prefix' + no;
        } else {
          no = no.replaceFirst(temp, '$prefix');
        }
      }
      valid_no.addAll([no]);
    }
    String num = valid_no.join(",");
    print(num);
  } */
}

==> smsalert-0.1.3.tar.gz: lib/src/messages.dart <==
// messages.dart
import 'dart:core';
import 'dart:convert' show json;
import 'package:http/http.dart' as http;
import './constants.dart';
import './utils.dart';

class Messages {
  final String _user;
  final String _pwd;

  const Messages(this._user, this._pwd);

//Send SMS
  Future<Map?> sendsms(data) async {
    Map? sendsms = await callapi('push', data);
    return (sendsms);
  }

//Schedule SMS
  Future<Map?> schedulesms(data) async {
    Map? schedulesms = await callapi('push', data);
    return (schedulesms);
  }

//Credit status
  Future<Map?> creditstatus() async {
    Map? creditstatus = await callapi('creditstatus');
    return (creditstatus);
  }

//SenderID list
  Future<Map?> senderlist() async {
    Map? senderID = await callapi('senderlist');
    return (senderID);
  }

//Generate otp
  Future<Map?> sendotp(data) async {
    Map? sendotp = await callapi('mverify', data);
    return (sendotp);
  }

//Verify otp
  Future<Map?> verifyotp(data) async {
    Map? verifyotp = await callapi('mverify', data);
    return (verifyotp);
  }

//used to send sms report
  Future<Map?> smsreport(data) async {
    Map? smsreport = await callapi('smscampaignlog', data);
    return (smsreport);
  }

//used to pull sms report
  Future<Map?> pullreport(data) async {
    Map? pullreport = await callapi('pull', data);
    return (pullreport);
  }

//get countries list
  Future<Map?> getcountries() async {
    Map? getcountries = await callapi('countrylist');
    return (getcountries);
  }

//used to send group sms
  Future<Map?> sendgroupsms(data) async {
    Map? sendgroupsms = await callapi('grouppush', data);
    return (sendgroupsms);
  }

//used to create contact
  Future<Map?> createcontact(data) async {
    Map? createcontact = await callapi('createcontact', data);
    return (createcontact);
  }

//Internal function for format number to be used only for this class.
/*   void _formatNumber(mobileno) {
    var prefix = 91;
    var nos = (mobileno.split(","));
    List valid_no = [];
    for (String no in nos) {
      no = no.replaceAll(new RegExp(r"(\D)"), "");
      no = no.replaceFirst(new RegExp(r"^[+0]+"), "");
      if (no.substring(0, '$prefix'.length) != '$prefix') {
        no = '$prefix' + no;
      }
      valid_no.addAll([no]);
    }
    String num = valid_no.join(",");
    print(num);
  }   */

///To call any API function.
//Parameters accepted:
  /// 1.(required) action_name ='<API url endpoint>' (eg.push,creditstatus,contactlist,etc)
  /*  2.(optional) var datas  = {                  
          'sender': 'CVDEMO',
          'mobileno': '918010551055',  
          'text': 'Hello from Dart!', 
          'route':'demo'
            }; */

  Future<Map?> callapi(action_name, [datas]) async {
    http.Client client = http.Client();

    String url = '${SMSALERT_API_BASE_URL}/$action_name.json';

    try {
      http.Response response = await client.post(Uri.parse(url),
          headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
            'Authorization': 'Basic ' + toAuthCredentials(_user, _pwd)
          },
          body: datas);

      return (json.decode(response.body));
    } catch (e) {
      return ({'Runtime Error': e});
    } finally {
      client.close();
    }
  }
}
